@@ -1,7 +1,7 @@
 package Web::Query;
 our $AUTHORITY = 'cpan:TOKUHIROM';
 # ABSTRACT: Yet another scraping library like jQuery
-$Web::Query::VERSION = '0.34';
+$Web::Query::VERSION = '0.35';
 use strict;
 use warnings;
 use 5.008001;
@@ -239,7 +239,20 @@ sub attr {
             ;
     }
 
-    $_->attr(@_) for @{$self->{trees}};
+    while( my( $attr, $value ) = splice @_, 0, 2 ) {
+        my $code = ref $value eq 'CODE' ? $value : undef;
+
+        for my $t ( @{$self->{trees}} ) {
+            if ( $code ) {
+                no warnings 'uninitialized';
+                my $orig = $_ = $t->attr($attr);
+                $code->();
+                next if $orig eq $_;
+                $value = $_;
+            }
+            $t->attr($attr => $value);
+        }
+    }
 
     return $self;
 }
@@ -651,7 +664,7 @@ Web::Query - Yet another scraping library like jQuery
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -914,7 +927,7 @@ of the first element.
 
 =head3 C< attr >
 
-Get/set the attribute value in element.
+Get/set attribute values.
 
 In getter mode, it'll return either the values of the attribute
 for all elements of the set, or only the first one depending of the calling context.
@@ -922,11 +935,20 @@ for all elements of the set, or only the first one depending of the calling cont
     my @values = $q->attr('style');      # style of all elements
     my $first_value = $q->attr('style'); # style of first element
 
-In setter mode, it'll set the attribute value for all elements, and return back
+In setter mode, it'll set attributes value for all elements, and return back
 the original object for easy chaining.
 
     $q->attr( 'alt' => 'a picture' )->find( ... );
 
+    # can pass more than 1 element too
+    $q->attr( alt => 'a picture', src => 'file:///...' );
+
+The value passed for an attribute can be a code ref. In that case,
+the code will be called with C<$_> set to the current attribute value.
+If the code modifies C<$_>, the attribute will be updated with the new value.
+
+    $q->attr( alt => sub { $_ ||= 'A picture' } );
+
 =head3 C< id >
 
 Get/set the elements's id attribute.
@@ -1082,6 +1104,29 @@ You can specify your own instance of L<LWP::UserAgent>.
 
     $Web::Query::UserAgent = LWP::UserAgent->new( agent => 'Mozilla/5.0' );
 
+=head1 TROUBLESHOOTING
+
+=head2 Can't get the content of script elements
+
+The <script> tag is treated differently by L<HTML::TreeBuilder>, the 
+parser used by Web::Query. To retrieve the content, you can use either
+the method C<html()> (with the caveat that the content will be escaped),
+or use L<Web::Query::LibXML>, which parse the 'script' element differently.
+
+    my $node = "<script>var x = '<p>foo</p>';</script>";
+
+    say Web::Query::wq( $node )->text;  
+        # nothing is printed!
+        
+    say Web::Query::wq( $node )->html;  
+        # var x = &#39;&lt;p&gt;foo&lt;/p&gt;&#39;;
+
+    say Web::Query::LibXML::wq( $node )->text;
+        # var x = '<p>foo</p>';
+        
+    say Web::Query::LibXML::wq( $node )->html;
+        # var x = '&lt;p&gt;foo&lt;/p&gt;';
+
 =head1 INCOMPATIBLE CHANGES
 
 =over 4
